@@ -11,16 +11,16 @@ class StationBasedOperator(Operator):
             "stations_dict": {
                 "type": "string",
                 "title": "Stations population",
-                "description": "Population of the operator's station agents"
+                "description": "Population of the operator's station agents",
             },
             "staff_dict": {
                 "x-display": "",
                 "title": "Staff population",
                 "description": "Population of the operator's staff agents",
-                "type": "string"
-            }
+                "type": "string",
+            },
         },
-        "required": ["stations_dict"]
+        "required": ["stations_dict"],
     }
 
     def __init__(self, simulation_model, agent_id, fleet_dict, stations_dict, **kwargs):
