@@ -1,6 +1,7 @@
 import logging
 import sys
 from starling_sim.basemodel.topology.osm_network import OSMNetwork
+from starling_sim.basemodel.topology.empty_network import EmptyNetwork
 from starling_sim.utils.config import config
 from geopy import distance
 
@@ -33,11 +34,6 @@ class Environment:
 
         for mode, info in topologies_dict.items():
 
-            network_file = info[0]
-            speeds_file = info[1]
-            if len(info) == 3:
-                weight_class = info[2]
-
             # see if paths of this topology should be stored
             if isinstance(store_paths, dict):
                 if mode not in store_paths:
@@ -47,8 +43,14 @@ class Environment:
             else:
                 store = store_paths
 
+            if info is None:
+                topology = EmptyNetwork(mode, store_paths=store)
             # create a topology object according to the given network type
-            if network == "osm":
+            elif network == "osm":
+                network_file = info[0]
+                speeds_file = info[1]
+                if len(info) == 3:
+                    weight_class = info[2]
                 topology = OSMNetwork(
                     mode,
                     network_file=network_file,
@@ -491,9 +493,15 @@ class Environment:
         """
         Call the topology localisations_nearest_nodes method.
 
+        If a list of modes is provided, consider only nodes that are present
+        in all provided topologies.
+
+        If a node as no neighbour, assign None
+
         :param x_coordinates: list of X coordinates of the localisations
         :param y_coordinates: list of Y coordinates of the localisations
         :param modes: topology modes
+
         :return: list of nearest nodes
         """
 
@@ -510,6 +518,10 @@ class Environment:
         else:
             target_graph = self.topologies[modes].graph
 
+        # if there is no candidate nodes, the nearest node is None
+        if len(target_graph.nodes) == 0:
+            return
+
         target_topology = OSMNetwork(modes, graph=target_graph)
 
         return target_topology.localisations_nearest_nodes(x_coordinates, y_coordinates)
@@ -621,23 +633,26 @@ class Environment:
         latitudes = stops_table["stop_lat"].values
         longitudes = stops_table["stop_lon"].values
 
-        # compute the stops nearest nodes
+        # compute each stop nearest node
         stops_table["nearest_node"] = self.localisations_nearest_nodes(longitudes, latitudes, modes)
 
-        for index, row in stops_table.iterrows():
+        # extend graph with stops if asked
+        if extend_graph:
 
-            # get stop and node information
-            nearest_node = row["nearest_node"]
+            for index, row in stops_table.iterrows():
 
-            # compute euclidean distance
-            nearest_loc = self.get_localisation(nearest_node, modes[0])
-            stop_loc = [row["stop_lat"], row["stop_lon"]]
-            eucl_dist = 1000 * distance.great_circle(nearest_loc, stop_loc).kilometers
+                # get stop and node information
+                nearest_node = row["nearest_node"]
 
-            # set correspondence
-            if eucl_dist > max_distance and extend_graph:
+                # if the node has a close neighbour, don't add a node
+                if nearest_node is not None:
+                    nearest_loc = self.get_localisation(nearest_node, modes[0])
+                    stop_loc = [row["stop_lat"], row["stop_lon"]]
+                    eucl_dist = 1000 * distance.great_circle(nearest_loc, stop_loc).kilometers
+                    if eucl_dist <= max_distance:
+                        continue
 
-                # extend the graph : add a new node at stop location
+                # otherwise, extend the graph : add a new node at stop location
                 self.add_node(
                     row["stop_id"],
                     {"y": row["stop_lat"], "x": row["stop_lon"], "osmid": row["stop_id"]},
